var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from "react";
import PropTypes from "prop-types";

import defines from '../../defines';
import { hasProperties } from '../../utils.js';

import withBasics from './withBasics.js';
import Contact from './Contact.js';
import Profiles from './Profiles.js';
import ModifiedDivider from '../internals/ModifiedDivider.js';

//Bloomer imports
import { Box, Image, Level, LevelItem, Title, Subtitle, Content } from 'bloomer';

var styles = {
    mainBox: {
        overflow: 'hidden',
        height: 'fit-content'
    },
    divider: {
        marginLeft: '-1.25rem',
        marginRight: '-1.25rem'
    },
    imageHolder: {
        marginTop: '-1.25rem',
        marginLeft: '-1.25rem',
        marginRight: '-1.25rem'
    },
    nameHolder: {
        textAlign: 'center',
        marginBottom: '1.5rem'
    },
    levelMenu: {
        flexDirection: 'column',
        paddingTop: '0.5rem',
        marginLeft: '-1rem',
        marginRight: '-1rem'
    },
    levelMenuItem: {
        fontSize: '1.25rem',
        textTransform: 'uppercase',
        display: 'block',
        width: '100%'
    },
    activeItem: {
        backgroundColor: '#3273dc',
        borderRadius: 2
    }
};

var BasicsSection = function BasicsSection(props) {
    var basics = props.basics,
        availableSections = props.availableSections,
        onMenuLinkClick = props.onMenuLinkClick,
        activeSection = props.activeSection,
        children = props.children,
        rest = _objectWithoutProperties(props, ["basics", "availableSections", "onMenuLinkClick", "activeSection", "children"]);

    return React.createElement(
        Box,
        _extends({}, rest, { style: styles.mainBox, id: "basics" }),
        hasProperties(basics, 'picture') ? React.createElement(
            "div",
            { style: styles.imageHolder },
            React.createElement(Image, { isRatio: "square", src: basics.picture })
        ) : null,
        React.createElement(
            "div",
            { style: styles.nameHolder },
            hasProperties(basics, 'name') ? React.createElement(
                Title,
                { isSize: 1 },
                basics.name
            ) : null,
            hasProperties(basics, 'label') ? React.createElement(
                Subtitle,
                { isSize: 3 },
                basics.label
            ) : null
        ),
        hasProperties(basics, 'summary') ? React.createElement(
            Content,
            null,
            React.createElement(
                "p",
                null,
                basics.summary
            )
        ) : null,
        React.createElement(ModifiedDivider, { style: styles.divider, isHidden: ['tablet', 'desktop', 'widescreen'] }),
        React.createElement(
            Level,
            { isDisplay: "flex-mobile", isHidden: ['tablet', 'desktop', 'widescreen'],
                style: styles.levelMenu },
            availableSections.map(function (menu) {
                return React.createElement(
                    LevelItem,
                    { href: "#" + menu, hasTextAlign: "centered", onClick: function onClick() {
                            return onMenuLinkClick(menu);
                        },
                        style: _extends({}, styles.levelMenuItem, activeSection === menu ? styles.activeItem : {}),
                        hasTextColor: activeSection === menu ? 'white' : 'dark', key: menu },
                    menu
                );
            })
        ),
        React.createElement("hr", { style: styles.divider }),
        children,
        hasProperties(basics, ['email', 'phone', 'website']) || hasProperties(basics, 'location') ? React.createElement(Contact, { email: basics.email, phone: basics.phone,
            website: basics.website, location: basics.location }) : null,
        (hasProperties(basics, ['email', 'phone', 'website']) || hasProperties(basics, 'location')) && hasProperties(basics, 'profiles') ? React.createElement("hr", { style: styles.divider }) : null,
        hasProperties(basics, 'profiles') ? React.createElement(Profiles, { profiles: basics.profiles }) : null
    );
};

BasicsSection.propTypes = process.env.NODE_ENV !== "production" ? {
    basics: PropTypes.shape({}),
    availableSections: PropTypes.arrayOf(PropTypes.oneOf(defines.sections)),
    onMenuLinkClick: PropTypes.func,
    activeSection: PropTypes.string
} : {};

BasicsSection.defaultProps = {
    basics: {},
    availableSections: [],
    onMenuLinkClick: function onMenuLinkClick() {},
    activeSection: 'basics'
};

export default withBasics(BasicsSection);