import React from "react";
import PropTypes from "prop-types";

import { hasProperties } from '../../utils.js';

//Bloomer imports
import { Title, Icon, Subtitle } from 'bloomer';

var styles = {
    mainDiv: {},
    subDiv: {
        marginBottom: '1.5rem'
    },
    iconStyle: {
        marginRight: '1.25rem'
    }
};

var renderAddress = function renderAddress(location) {
    var address = '';
    if (hasProperties(location, 'address')) {
        address += location.address;
    }
    if (hasProperties(location, 'city')) {
        address += ", " + location.city;
    }
    if (hasProperties(location, 'region')) {
        address += ", " + location.region;
    }
    if (hasProperties(location, 'countryCode')) {
        address += " (" + location.countryCode + ")";
    }
    if (hasProperties(location, 'postalCode')) {
        address += ", " + location.postalCode;
    }
    return address;
};

var Contact = function Contact(props) {
    var phone = props.phone,
        location = props.location,
        email = props.email,
        website = props.website;


    return React.createElement(
        "div",
        { style: styles.mainDiv },
        React.createElement(
            Title,
            { isSize: 4 },
            "Contact"
        ),
        phone && phone.length ? React.createElement(
            "div",
            { style: styles.subDiv },
            React.createElement(
                Subtitle,
                { isSize: 6, isSpaced: true },
                React.createElement(Icon, { isSize: "small", className: "fas fa-phone", style: styles.iconStyle }),
                phone
            )
        ) : null,
        React.createElement(
            "div",
            { style: styles.subDiv },
            React.createElement(
                Subtitle,
                { isSize: 6, isSpaced: true },
                React.createElement(Icon, { isSize: "small", className: "fas fa-map-marker-alt", style: styles.iconStyle }),
                renderAddress(location)
            )
        ),
        React.createElement(
            "div",
            { style: styles.subDiv },
            email && email.length ? React.createElement(
                Subtitle,
                { isSize: 6, isSpaced: true, style: { marginBottom: '0.25rem' } },
                React.createElement(Icon, { isSize: "small", className: "fas fa-envelope", style: styles.iconStyle }),
                React.createElement(
                    "a",
                    { href: "mailto:" + email, target: "_top" },
                    email
                )
            ) : null,
            website && website.length ? React.createElement(
                Subtitle,
                { isSize: 6, isSpaced: true },
                React.createElement(Icon, { isSize: "small", className: "fas fa-link", style: styles.iconStyle }),
                React.createElement(
                    "a",
                    { href: website, target: "_blank" },
                    website
                )
            ) : null
        )
    );
};

Contact.propTypes = process.env.NODE_ENV !== "production" ? {
    email: PropTypes.string,
    phone: PropTypes.string,
    website: PropTypes.string,
    location: PropTypes.shape({})
} : {};

Contact.defaultProps = {
    email: null,
    phone: null,
    website: null,
    location: {}
};

export default Contact;