import React, { Component } from 'react';
import PropTypes from 'prop-types';

import { hasProperties } from '../../utils.js';

//Bloomer imports
import { Columns, Column, Title, Subtitle, Content, Tag } from 'bloomer';

var styles = {
    itemDiv: {},
    dateDiv: {
        fontSize: '0.8em'
    },
    dateSpan: {
        marginLeft: '0.4rem',
        marginRight: '0.4rem',
        fontStyle: 'italic'
    },
    highlightList: {
        listStyle: 'square',
        marginLeft: 20
    },
    highlightElement: {},
    tagsList: {},
    tagElement: {
        marginLeft: '0.3rem'
    }
};

var GenericElement = function GenericElement(props) {
    var item = props.item,
        highlightType = props.highlightType;


    return React.createElement(
        'div',
        { style: styles.itemDiv },
        React.createElement(
            Columns,
            null,
            React.createElement(
                Column,
                { isSize: '1/2' },
                hasProperties(item, 'title') ? React.createElement(
                    Title,
                    { isSize: 5 },
                    hasProperties(item, 'url') ? React.createElement(
                        'a',
                        { href: item.url },
                        item.title
                    ) : item.title
                ) : null,
                hasProperties(item, 'subtitle') ? React.createElement(
                    Subtitle,
                    { isSize: 5 },
                    item.subtitle
                ) : null
            ),
            hasProperties(item, 'start') || hasProperties(item, 'end') ? React.createElement(
                Column,
                { isSize: '1/2', hasTextAlign: 'right', hasTextColor: 'info' },
                React.createElement(
                    'div',
                    { style: styles.dateDiv },
                    hasProperties(item, 'start') ? React.createElement(
                        'span',
                        { style: styles.dateSpan },
                        item.start
                    ) : null,
                    hasProperties(item, ['start', 'end']) ? React.createElement(
                        'span',
                        null,
                        'to'
                    ) : null,
                    hasProperties(item, 'end') ? React.createElement(
                        'span',
                        { style: styles.dateSpan },
                        item.end
                    ) : null
                )
            ) : null
        ),
        hasProperties(item, 'summary') ? React.createElement(
            Content,
            null,
            item.summary
        ) : null,
        hasProperties(item, 'highlights') ? highlightType === 'list' ? React.createElement(
            'ul',
            { style: styles.highlightList },
            item.highlights.map(function (highlight, index) {
                return React.createElement(
                    'li',
                    { style: styles.highlightElement, key: index },
                    highlight
                );
            })
        ) : React.createElement(
            'div',
            { style: styles.tagsList },
            item.highlights.map(function (highlight, index) {
                return React.createElement(
                    Tag,
                    { style: styles.tagElement, key: index, isColor: 'info' },
                    highlight
                );
            })
        ) : null
    );
};

GenericElement.propTypes = process.env.NODE_ENV !== "production" ? {
    item: PropTypes.shape({
        title: PropTypes.string,
        subtitle: PropTypes.string,
        summary: PropTypes.string,
        url: PropTypes.string,
        start: PropTypes.string,
        end: PropTypes.string,
        highlights: PropTypes.arrayOf(PropTypes.string)
    }).isRequired,
    highlightType: PropTypes.oneOf(['list', 'tags'])
} : {};

GenericElement.defaultProps = {
    highlightType: 'list'
};

export default GenericElement;