import React from "react";
import PropTypes from "prop-types";

import { hasProperties } from '../../utils.js';

import withLanguages from './withLanguages.js';

import GenericList from '../internals/GenericList.js';

import { Column, Card, CardHeader, CardHeaderIcon, Icon, CardHeaderTitle, CardContent, Title, Subtitle } from 'bloomer';

var styles = {
    icon: {
        width: 40,
        paddingLeft: 8,
        display: 'flex',
        justifyContent: 'center',
        alignItems: 'center'
    },
    heading: {
        textTransform: 'uppercase'
    }
};

var Languages = function Languages(props) {
    var languages = props.languages;


    if (!languages.length) {
        return null;
    }

    return React.createElement(
        Column,
        { isSize: "1/2" },
        React.createElement(
            Card,
            { style: { height: '100%' } },
            React.createElement(
                CardHeader,
                null,
                React.createElement(CardHeaderIcon, { render: function render() {
                        return React.createElement(
                            "div",
                            { style: styles.icon },
                            React.createElement(Icon, { className: "fas fa-language" })
                        );
                    } }),
                React.createElement(
                    CardHeaderTitle,
                    { style: styles.heading },
                    "Languages"
                )
            ),
            React.createElement(
                CardContent,
                null,
                languages.map(function (item, index, items) {
                    return [hasProperties(item, 'name') ? React.createElement(
                        Title,
                        { isSize: 5, key: "name_" + index },
                        item.name
                    ) : null, hasProperties(item, 'level') ? React.createElement(
                        Subtitle,
                        { isSize: 5, hasTextColor: "info", key: "level_" + index },
                        item.level
                    ) : null, index !== items.length - 1 ? React.createElement("hr", null) : null];
                })
            )
        )
    );
};

Languages.propTypes = process.env.NODE_ENV !== "production" ? {
    languages: PropTypes.arrayOf(PropTypes.shape({}))
} : {};

Languages.defaultProps = {
    languages: []
};

export default withLanguages(Languages);