import React from "react";
import PropTypes from "prop-types";

import { hasProperties } from '../../utils.js';

import withSkills from './withSkills.js';

//Bloomer imports
import { Title, Subtitle, Progress, Tag } from 'bloomer';

var styles = {
    mainDiv: {
        marginBottom: '1.25rem'
    },
    skillsList: {},
    skills: {
        marginBottom: '1rem'
    },
    skillTitle: {
        marginBottom: '0.5rem'
    },
    skillProgress: {
        marginBottom: '0.5rem'
    },
    skillTags: {
        textAlign: 'right'
    },
    tag: {
        marginLeft: '0.2rem'
    }
};

var levelToProgress = function levelToProgress(level) {
    switch (level) {
        case 'Basic':
            return 1;
        case 'Initiated':
            return 2;
        case 'Average':
            return 3;
        case 'Competent':
            return 4;
        case 'Master':
            return 5;
        default:
            return 3;
    }
};

var Skills = function Skills(props) {
    var skills = props.skills;


    if (!skills.length) {
        return null;
    }

    return React.createElement(
        "div",
        { id: "skills", style: styles.mainDiv },
        React.createElement(
            Title,
            { isSize: 4 },
            "Profesionnal Skills"
        ),
        React.createElement(
            "div",
            { style: styles.skillsList },
            skills.map(function (skill, index) {
                return React.createElement(
                    "div",
                    { style: styles.skills, key: index },
                    hasProperties(skill, 'name') ? React.createElement(
                        Subtitle,
                        { isSize: 5, style: styles.skillTitle },
                        skill.name
                    ) : null,
                    hasProperties(skill, 'level') ? React.createElement(Progress, { isColor: "primary", value: levelToProgress(skill.level), max: 5,
                        style: styles.skillProgress }) : null,
                    hasProperties(skill, 'keywords') ? React.createElement(
                        "div",
                        { style: styles.skillTags },
                        skill.keywords.map(function (keyword, index) {
                            return React.createElement(
                                Tag,
                                { isColor: "info", style: styles.tag, key: index },
                                keyword
                            );
                        })
                    ) : null
                );
            })
        )
    );
};

Skills.propTypes = process.env.NODE_ENV !== "production" ? {
    skills: PropTypes.arrayOf(PropTypes.shape({}))
} : {};

Skills.defaultProps = {
    skills: []
};

export default withSkills(Skills);