'use strict';

exports.__esModule = true;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _utils = require('../../utils.js');

var _bloomer = require('bloomer');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var styles = {
    itemDiv: {},
    dateDiv: {
        fontSize: '0.8em'
    },
    dateSpan: {
        marginLeft: '0.4rem',
        marginRight: '0.4rem',
        fontStyle: 'italic'
    },
    highlightList: {
        listStyle: 'square',
        marginLeft: 20
    },
    highlightElement: {},
    tagsList: {},
    tagElement: {
        marginLeft: '0.3rem'
    }
};

//Bloomer imports


var GenericElement = function GenericElement(props) {
    var item = props.item,
        highlightType = props.highlightType;


    return _react2.default.createElement(
        'div',
        { style: styles.itemDiv },
        _react2.default.createElement(
            _bloomer.Columns,
            null,
            _react2.default.createElement(
                _bloomer.Column,
                { isSize: '1/2' },
                (0, _utils.hasProperties)(item, 'title') ? _react2.default.createElement(
                    _bloomer.Title,
                    { isSize: 5 },
                    (0, _utils.hasProperties)(item, 'url') ? _react2.default.createElement(
                        'a',
                        { href: item.url },
                        item.title
                    ) : item.title
                ) : null,
                (0, _utils.hasProperties)(item, 'subtitle') ? _react2.default.createElement(
                    _bloomer.Subtitle,
                    { isSize: 5 },
                    item.subtitle
                ) : null
            ),
            (0, _utils.hasProperties)(item, 'start') || (0, _utils.hasProperties)(item, 'end') ? _react2.default.createElement(
                _bloomer.Column,
                { isSize: '1/2', hasTextAlign: 'right', hasTextColor: 'info' },
                _react2.default.createElement(
                    'div',
                    { style: styles.dateDiv },
                    (0, _utils.hasProperties)(item, 'start') ? _react2.default.createElement(
                        'span',
                        { style: styles.dateSpan },
                        item.start
                    ) : null,
                    (0, _utils.hasProperties)(item, ['start', 'end']) ? _react2.default.createElement(
                        'span',
                        null,
                        'to'
                    ) : null,
                    (0, _utils.hasProperties)(item, 'end') ? _react2.default.createElement(
                        'span',
                        { style: styles.dateSpan },
                        item.end
                    ) : null
                )
            ) : null
        ),
        (0, _utils.hasProperties)(item, 'summary') ? _react2.default.createElement(
            _bloomer.Content,
            null,
            item.summary
        ) : null,
        (0, _utils.hasProperties)(item, 'highlights') ? highlightType === 'list' ? _react2.default.createElement(
            'ul',
            { style: styles.highlightList },
            item.highlights.map(function (highlight, index) {
                return _react2.default.createElement(
                    'li',
                    { style: styles.highlightElement, key: index },
                    highlight
                );
            })
        ) : _react2.default.createElement(
            'div',
            { style: styles.tagsList },
            item.highlights.map(function (highlight, index) {
                return _react2.default.createElement(
                    _bloomer.Tag,
                    { style: styles.tagElement, key: index, isColor: 'info' },
                    highlight
                );
            })
        ) : null
    );
};

GenericElement.propTypes = process.env.NODE_ENV !== "production" ? {
    item: _propTypes2.default.shape({
        title: _propTypes2.default.string,
        subtitle: _propTypes2.default.string,
        summary: _propTypes2.default.string,
        url: _propTypes2.default.string,
        start: _propTypes2.default.string,
        end: _propTypes2.default.string,
        highlights: _propTypes2.default.arrayOf(_propTypes2.default.string)
    }).isRequired,
    highlightType: _propTypes2.default.oneOf(['list', 'tags'])
} : {};

GenericElement.defaultProps = {
    highlightType: 'list'
};

exports.default = GenericElement;
module.exports = exports['default'];